@@ -24,6 +24,14 @@ def test_data(installdir):  # pylint: disable=redefined-outer-name
     }
 
 
+@pytest.fixture(scope="session")
+def oras_container(tmp_path_factory):
+    folder = tmp_path_factory.mktemp("oras-img")
+    return folder, Client.pull(
+        "oras://ghcr.io/singularityhub/github-ci:latest", pull_folder=str(folder)
+    )
+
+
 @pytest.fixture(scope="session")
 def docker_container(tmp_path_factory):
     folder = tmp_path_factory.mktemp("docker-img")
